@@ -33,7 +33,7 @@ class KMenuEdit : public KXmlGuiWindow
 
 public:
     KMenuEdit();
-    ~KMenuEdit();
+    ~KMenuEdit() override;
 
     void selectMenu(const QString &menu);
     void selectMenuEntry(const QString &menuEntry);
@@ -44,7 +44,7 @@ public:
 protected:
     void setupView();
     void setupActions();
-    bool queryClose() Q_DECL_OVERRIDE;
+    bool queryClose() override;
 
 protected Q_SLOTS:
     void slotSave();
@@ -53,12 +53,12 @@ protected Q_SLOTS:
     void slotConfigure();
 
 protected:
-    TreeView           *m_tree;
-    BasicTab           *m_basicTab;
-    QSplitter          *m_splitter;
+    TreeView *m_tree = nullptr;
+    BasicTab *m_basicTab = nullptr;
+    QSplitter *m_splitter = nullptr;
 
-    QAction *m_actionDelete;
-    bool m_showHidden;
+    QAction *m_actionDelete = nullptr;
+    bool m_showHidden = false;
 };
 
 #endif
